@@ -1,5 +1,5 @@
 from collections import defaultdict
-from datetime import datetime, timedelta
+from datetime import datetime, timedelta, timezone
 from typing import Any, List, Union
 from unittest import mock
 
@@ -86,6 +86,15 @@ def test_config_pydantic_validation():
         assert config.start_offset.name == offset_name
 
 
+def test_subscribe_with_csp_engine_timestamp_only_if_encoding_expected():
+    config = KafkaConfiguration(broker="dummy")
+    ReadWriteKafka(config=config, encoding_with_engine_timestamps=False, subscribe_with_csp_engine_timestamp=False)
+    ReadWriteKafka(config=config, encoding_with_engine_timestamps=True, subscribe_with_csp_engine_timestamp=False)
+    ReadWriteKafka(config=config, encoding_with_engine_timestamps=True, subscribe_with_csp_engine_timestamp=False)
+    with pytest.raises(ValidationError):
+        ReadWriteKafka(config=config, encoding_with_engine_timestamps=False, subscribe_with_csp_engine_timestamp=True)
+
+
 @mock.patch("csp.adapters.kafka.KafkaAdapterManager", autospec=True)
 @pytest.mark.parametrize("by_key", [True, False])
 def test_kafka_engine_replay_write(mock_object, by_key):
@@ -107,7 +116,7 @@ def test_kafka_engine_replay_write(mock_object, by_key):
         modules=[setter, kafka_engine_replay_write, AddChannelsToGraphOutput()],
         channels=MyGatewayChannels(),
     )
-    out = csp.run(gateway_writing.graph, starttime=datetime.utcnow(), endtime=timedelta(seconds=5))
+    out = csp.run(gateway_writing.graph, starttime=datetime.now(timezone.utc), endtime=timedelta(seconds=5))
     assert mock_publish.call_count == 1
     assert mock_subscribe.call_count == 0
 
@@ -158,7 +167,7 @@ def test_kafka_engine_replay_read_and_write_read(mock_object, read_write_mode):
         modules=[setter, kafka_engine_replay_write, setter],
         channels=MyGatewayChannels(),
     )
-    csp.run(gateway_writing.graph, starttime=datetime.utcnow(), endtime=timedelta(seconds=5))
+    csp.run(gateway_writing.graph, starttime=datetime.now(timezone.utc), endtime=timedelta(seconds=5))
     if read_write_mode is ReadWriteMode.READ_AND_WRITE:
         assert mock_publish.call_count == 1
     else:
@@ -199,7 +208,7 @@ def test_kafka_read_write_fails_with_dict_basket(mock_object):
     with pytest.raises((TypeError, AttributeError)):
         csp.run(
             gateway_writing.graph,
-            starttime=datetime.utcnow(),
+            starttime=datetime.now(timezone.utc),
             endtime=timedelta(seconds=5),
         )
 
@@ -248,7 +257,7 @@ def test_kafka_read_write_read(mock_object, encoding_with_engine_timestamps, cap
         modules=[setter, kafka_reader, setter],
         channels=MyGatewayChannelsWithNumpyStruct(),
     )
-    csp.run(gateway_writing.graph, starttime=datetime.utcnow(), endtime=timedelta(seconds=5))
+    csp.run(gateway_writing.graph, starttime=datetime.now(timezone.utc), endtime=timedelta(seconds=5))
     calls = mock_publish.call_args_list
     topic_and_call_args = defaultdict(lambda *a, **kw: defaultdict(int))
     for call in calls:
@@ -303,7 +312,7 @@ def test_kafka_read_write_write(mock_object):
         modules=[kafka_writer, AddChannelsToGraphOutput()],
         channels=MyGatewayChannelsWithNumpyStruct(),
     )
-    out = csp.run(gateway_writing.graph, starttime=datetime.utcnow(), endtime=timedelta(seconds=5))
+    out = csp.run(gateway_writing.graph, starttime=datetime.now(timezone.utc), endtime=timedelta(seconds=5))
     assert not mock_publish.call_args_list
     assert len(out[MyGatewayChannelsWithNumpyStruct.my_channel]) == 1
     assert out[MyGatewayChannelsWithNumpyStruct.my_channel][0][1].foo == 9.1
@@ -355,7 +364,7 @@ def test_kafka_read_write_write_overwrite_id_timestamp(mock_object, use_struct_i
         modules=[kafka_writer, AddChannelsToGraphOutput()],
         channels=MyGatewayChannelsWithNumpyStruct(),
     )
-    out = csp.run(gateway_writing.graph, starttime=datetime.utcnow(), endtime=timedelta(seconds=5))
+    out = csp.run(gateway_writing.graph, starttime=datetime.now(timezone.utc), endtime=timedelta(seconds=5))
     assert not mock_publish.call_args_list
     assert len(out[MyGatewayChannelsWithNumpyStruct.my_channel]) == 1
     assert out[MyGatewayChannelsWithNumpyStruct.my_channel][0][1].foo == 9.1
@@ -415,7 +424,7 @@ def test_kafka_read_write_filter_write(mock_object, my_flag):
         modules=[kafka_writer, AddChannelsToGraphOutput()],
         channels=MyGatewayChannelsWithNumpyStruct(),
     )
-    out = csp.run(gateway_writing.graph, starttime=datetime.utcnow(), endtime=timedelta(seconds=5))
+    out = csp.run(gateway_writing.graph, starttime=datetime.now(timezone.utc), endtime=timedelta(seconds=5))
     assert not mock_publish.call_args_list
     assert len(out[MyGatewayChannelsWithNumpyStruct.my_channel]) == 1
     assert out[MyGatewayChannelsWithNumpyStruct.my_channel][0][1].foo == 9.1
@@ -482,7 +491,7 @@ def test_kafka_read_write_filter_read(mock_object, encoding_with_engine_timestam
         modules=[setter, kafka_writer, setter],
         channels=MyGatewayChannelsWithNumpyStruct(),
     )
-    csp.run(gateway_writing.graph, starttime=datetime.utcnow(), endtime=timedelta(seconds=5))
+    csp.run(gateway_writing.graph, starttime=datetime.now(timezone.utc), endtime=timedelta(seconds=5))
     calls = mock_publish.call_args_list
     topic_and_call_args = defaultdict(lambda *a, **kw: defaultdict(int))
     for call in calls:
